/************************************************************************************//**
* \file         Demo\ARMCM4_TM4C_DK_TM4C123G_IAR\Prog\main.c
* \brief        Demo program application source file.
* \ingroup      Prog_ARMCM4_TM4C_DK_TM4C123G_IAR
* \internal
*----------------------------------------------------------------------------------------
*                          C O P Y R I G H T
*----------------------------------------------------------------------------------------
*   Copyright (c) 2014  by Feaser    http://www.feaser.com    All rights reserved
*
*----------------------------------------------------------------------------------------
*                            L I C E N S E
*----------------------------------------------------------------------------------------
* This file is part of OpenBLT. OpenBLT is free software: you can redistribute it and/or
* modify it under the terms of the GNU General Public License as published by the Free
* Software Foundation, either version 3 of the License, or (at your option) any later
* version.
*
* OpenBLT is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
* without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
* PURPOSE. See the GNU General Public License for more details.
*
* You have received a copy of the GNU General Public License along with OpenBLT. It 
* should be located in ".\Doc\license.html". If not, contact Feaser to obtain a copy.
* 
* \endinternal
****************************************************************************************/

/****************************************************************************************
* Include files
****************************************************************************************/
#include "header.h"                                    /* generic header               */


/****************************************************************************************
* Function prototypes
****************************************************************************************/
static void Init(void);


/************************************************************************************//**
** \brief     This is the entry point for the bootloader application and is called 
**            by the reset interrupt vector after the C-startup routines executed.
** \return    none.
**
****************************************************************************************/
void main(void)
{
  /* initialize the microcontroller */
  Init();
  /* initialize the bootloader interface */
  BootComInit();

  /* start the infinite program loop */
  while (1)
  {
    /* toggle LED with a fixed frequency */
    LedToggle();
    /* check for bootloader activation request */
    BootComCheckActivationRequest();
  }
} /*** end of main ***/


/************************************************************************************//**
** \brief     Initializes the microcontroller.
** \return    none.
**
****************************************************************************************/
static void Init(void)
{
  /* enable lazy stacking for interrupt handlers. this allows floating-point 
   * instructions to be used within interrupt handlers, but at the expense of extra
   * stack usage.
   */
  FPULazyStackingEnable();
  /* set the clocking to run at 50MHz from the PLL */
  SysCtlClockSet(SYSCTL_SYSDIV_4 | SYSCTL_USE_PLL | SYSCTL_XTAL_16MHZ | SYSCTL_OSC_MAIN);
  /* init the led driver */
  LedInit();
  /* init the timer driver */
  TimeInit();
} /*** end of Init ***/


#ifdef DEBUG
/************************************************************************************//**
** \brief     Called when a runtime assertion failed. It stores information about
**            where the assertion occurred and halts the software program.
** \param     pcFilename Name of the source file where the assertion occurred.
** \param     ulLine Linenumber in the source file where the assertion occurred. 
** \return    none.
**
****************************************************************************************/
void __error__(char *pcFilename, unsigned long ulLine)
{
  /* hang the software so that it requires a hard reset */
  for(;;) 
  { 
  }
} /*** end of __error__ ***/
#endif


/*********************************** end of main.c *************************************/
